@@ -1,26 +1,24 @@
 def importdir(_dirname_, _package_, _globals_):
-  import os, importlib
-  for f in os.listdir(_dirname_):
-    if f.startswith('_') or f.startswith('.'):
-      continue
-    if f.endswith('.py'):
-      modname = f[:-len('.py')]
-    elif os.path.isdir(os.path.join(_dirname_, f)):
-      modname = f
+  import pathlib, importlib
+  _dirname_ = pathlib.Path(_dirname_)
+  for f in _dirname_.glob('[!_.]*'):
+    if f.is_file() and f.suffix == '.py':
+      modname = f.stem
+    elif f.is_dir():
+      modname = f.name
     else:
       continue
     mod = importlib.import_module('.{}'.format(modname), _package_)
     _globals_.update(**{modname: mod})
 
 def importdir_deep(_dirname_, _package_, _globals_, filter_mod=lambda m, k, v: not k.startswith('_')):
-  import os, importlib
-  for f in os.listdir(_dirname_):
-    if f.startswith('_') or f.startswith('.'):
-      continue
-    if f.endswith('.py'):
-      modname = f[:-len('.py')]
-    elif os.path.isdir(os.path.join(_dirname_, f)):
-      modname = f
+  import pathlib, importlib
+  _dirname_ = pathlib.Path(_dirname_)
+  for f in _dirname_.glob('[!_.]*'):
+    if f.is_file() and f.suffix == '.py':
+      modname = f.stem
+    elif f.is_dir():
+      modname = f.name
     else:
       continue
     mod = importlib.import_module('.{}'.format(modname), _package_)
