@@ -1,15 +1,11 @@
-import os
-import click
-import nbformat
-from appyter.ext.fs import Filesystem
 from appyter.cli import cli
-from appyter.context import get_env, get_jinja2_env
 from appyter.ext.click import click_argument_setenv
+from appyter.parse.nb import nb_from_ipynb_io, nb_to_ipynb_io
 
 @cli.command(help='Clean an appyters output & metadata to minimize unnecessary data transfers in production')
 @click_argument_setenv('ipynb', type=str, envvar='APPYTER_IPYNB')
 def nbclean(ipynb, **kwargs):
-  nb = nbformat.read(open(ipynb, 'r'), as_version=4)
+  nb = nb_from_ipynb_io(open(ipynb, 'r'))
   for cell in nb.cells:
     if cell['cell_type'] == 'code':
       cell['execution_count'] = None
@@ -22,4 +18,4 @@ def nbclean(ipynb, **kwargs):
         del cell['execution_count']
   if 'widgets' in nb['metadata']:
     del nb['metadata']['widgets']
-  nbformat.write(nb, open(ipynb, 'w'))
+  nb_to_ipynb_io(nb, open(ipynb, 'w'))
