@@ -28,3 +28,14 @@ class FloatField(Field):
     else:
       # Raw value would fail otherwise
       return True
+
+  def to_jsonschema(self):
+    return dict(super().to_jsonschema(), type='numeric')
+
+  def to_cwl(self):
+    return dict(super().to_cwl(), type='float')
+
+  def to_click(self):
+    args, kwargs = super().to_click()
+    kwargs['type'] = float
+    return args, kwargs
