@@ -8,8 +8,8 @@ def url_for(directory, public=False, **kwargs):
     try:
       from flask import url_for as _url_for
       modified_directory = '.'.join(('__main__', directory)) if directory == 'static' else directory
-      url = _url_for(modified_directory, **kwargs)
-    except:
+      url = _url_for(modified_directory, **kwargs).rstrip('/')
+    except RuntimeError:
       pass
   #
   if url is None:
@@ -18,11 +18,13 @@ def url_for(directory, public=False, **kwargs):
     assert filename is not None
     url = join_url(config['PREFIX'], directory, filename)
   #
-  if public:
+  if config['MODE'] == 'default' and public:
     # url_for public modifier -- return the public facing url
     try:
       from flask import request
       url = join_url(request.url_root, url)
+    except RuntimeError:
+      raise
     except:
       pass
   #
